#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 protolude
version:              0.3.0
visibility:           public
id:                   protolude-0.3.0-Jt5uzgyZml7KpPuQIVvvn2
key:                  protolude-0.3.0-Jt5uzgyZml7KpPuQIVvvn2
license:              MIT
copyright:            2016-2020 Stephen Diehl
maintainer:           stephen.m.diehl@gmail.com
author:               Stephen Diehl
homepage:             https://github.com/sdiehl/protolude
synopsis:             A small prelude.
description:          A sensible set of defaults for writing custom Preludes.
category:             Prelude
abi:                  353a2d179fd4732a2de90868cd485f5a
exposed:              True
exposed-modules:
    Protolude Protolude.Applicative Protolude.Base Protolude.Bifunctor
    Protolude.Bool Protolude.CallStack Protolude.Conv
    Protolude.ConvertText Protolude.Debug Protolude.Either
    Protolude.Error Protolude.Exceptions Protolude.Functor
    Protolude.List Protolude.Monad Protolude.Panic Protolude.Partial
    Protolude.Safe Protolude.Semiring Protolude.Show Protolude.Unsafe

import-dirs:          /usr/lib/ghc-8.10.5/site-local/protolude-0.3.0
library-dirs:         /usr/lib/ghc-8.10.5/site-local/protolude-0.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/protolude-0.3.0
hs-libraries:         HSprotolude-0.3.0-Jt5uzgyZml7KpPuQIVvvn2
depends:
    array-0.5.4.0 async-2.2.3-6QbaQgrhqs02Gm74dJYuzp base-4.14.2.0
    bytestring-0.10.12.0 containers-0.6.4.1 deepseq-1.4.4.0
    ghc-prim-0.6.1 hashable-1.3.2.0-L2CDkY7lZtECinpkHRj0mo mtl-2.2.2
    stm-2.5.0.1 text-1.2.4.1 transformers-0.5.6.2
    transformers-compat-0.6.6-8xD7tdhdla21VYsnm1hEvk

haddock-interfaces:   /usr/share/doc/haskell-protolude/html/protolude.haddock
haddock-html:         /usr/share/doc/haskell-protolude/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

